ConstDecodeError

Enum ConstDecodeError 

#[non_exhaustive]
pub enum ConstDecodeError { Overflow, InsufficientData(InsufficientData), Other(&'static str), }
Decoding varint error.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Overflow

The buffer does not contain a valid LEB128 encoding.



InsufficientData(InsufficientData)

The buffer does not contain enough data to decode.



Other(&'static str)

A custom error message.

Implementations

Source

impl ConstDecodeError

pub const fn overflow() -> Self

Creates a new ConstDecodeError::Overflow indicating that the decoded value would overflow the target type.

pub const fn insufficient_data(available: usize) -> Self

Creates a new ConstDecodeError::InsufficientData indicating that the buffer does not have enough data to decode a value.

pub const fn insufficient_data_with_required( required: NonZeroUsize, available: usize, ) -> Self

Creates a new ConstDecodeError::InsufficientData with the required and available bytes.

Panics

Panics if required is not greater than available.

pub const fn other(msg: &'static str) -> Self

Creates a new ConstDecodeError::Other with the given message.

pub const fn into_decode_error(self) -> DecodeError

Converts this ConstDecodeError into a DecodeError.

Example
use varing::{ConstDecodeError, DecodeError};

let const_error = ConstDecodeError::other("Other error message");
let error: DecodeError = const_error.into_decode_error();

let const_error_overflow = ConstDecodeError::overflow();
let error_overflow: DecodeError = const_error_overflow.into_decode_error();

let const_error_insufficient = ConstDecodeError::insufficient_data(5);
let error_insufficient: DecodeError = const_error_insufficient.into_decode_error();