pub const fn encode_date(date: &Date) -> DateBufferAvailable on crate feature
time_0_3 only.Expand description
Encodes a Date value into LEB128 variable length format, and writes it to the buffer.
pub const fn encode_date(date: &Date) -> DateBuffertime_0_3 only.Encodes a Date value into LEB128 variable length format, and writes it to the buffer.