encode_date_to

Function encode_date_to 

pub const fn encode_date_to(
    date: &Date,
    buf: &mut [u8],
) -> Result<NonZeroUsize, ConstEncodeError>
Available on crate feature time_0_3 only.
Encodes a Date value into LEB128 variable length format, and writes it to the buffer.

Returns the number of bytes written to the buffer.